@@ -1,4 +1,4 @@
-"""Promptware runtime support modules."""
+"""AssertLang runtime support modules."""
 
 from assertlang.runtime.contracts import (
     ContractViolationError,
@@ -15,7 +15,18 @@ from assertlang.runtime.contracts import (
     should_check_preconditions,
 )
 
+from assertlang.runtime.stdlib import (
+    Result,
+    Ok,
+    Error,
+    al_str,
+    al_list,
+    al_math,
+    al_result,
+)
+
 __all__ = [
+    # Contract validation
     "ContractViolationError",
     "OldValue",
     "ValidationMode",
@@ -28,4 +39,13 @@ __all__ = [
     "should_check_invariants",
     "should_check_postconditions",
     "should_check_preconditions",
+
+    # Standard library
+    "Result",
+    "Ok",
+    "Error",
+    "al_str",
+    "al_list",
+    "al_math",
+    "al_result",
 ]
