@@ -93,6 +93,95 @@ class JavaScriptGenerator:
         self.function_return_types: Dict[str, IRType] = {}
         self.method_return_types: Dict[str, Dict[str, IRType]] = {}
         self.current_class: Optional[str] = None
+        self.defined_classes: Set[str] = set()  # BUG FIX #5: Track class names for 'new' keyword
+        self.reassigned_variables: Set[str] = set()  # BUG FIX: Track variables that are reassigned
+
+    # ========================================================================
+    # Type Analysis
+    # ========================================================================
+
+    def _is_integer_expression(self, expr: IRExpression) -> bool:
+        """Check if an expression has an integer type."""
+        if isinstance(expr, IRLiteral):
+            return expr.literal_type == LiteralType.INTEGER
+        elif isinstance(expr, IRIdentifier):
+            # Check if variable has int type
+            var_type = self.variable_types.get(expr.name)
+            if var_type and hasattr(var_type, 'name'):
+                return var_type.name == 'int'
+            return False
+        elif isinstance(expr, IRBinaryOp):
+            # Integer operations return integers if both operands are integers
+            if expr.op in [BinaryOperator.ADD, BinaryOperator.SUBTRACT, BinaryOperator.MULTIPLY,
+                          BinaryOperator.DIVIDE, BinaryOperator.MODULO]:
+                return self._is_integer_expression(expr.left) and self._is_integer_expression(expr.right)
+            return False
+        elif isinstance(expr, IRCall):
+            # Check if function returns int
+            return_type = self.function_return_types.get(expr.function)
+            if return_type and hasattr(return_type, 'name'):
+                return return_type.name == 'int'
+            return False
+        return False
+
+    # ========================================================================
+    # Variable Analysis
+    # ========================================================================
+
+    def _analyze_reassignments(self, statements: List[IRStatement]) -> Set[str]:
+        """
+        Analyze which variables are reassigned in a block of statements.
+
+        Returns a set of variable names that are reassigned (not just declared).
+        """
+        reassigned = set()
+        declared = set()
+
+        def analyze_stmt(stmt: IRStatement):
+            if isinstance(stmt, IRAssignment):
+                # BUG FIX #2: Handle IRPropertyAccess targets (self.field)
+                # Only track simple variable names, not property assignments
+                if isinstance(stmt.target, str):
+                    var_name = stmt.target
+                    if stmt.is_declaration:
+                        declared.add(var_name)
+                    else:
+                        # This is a reassignment
+                        reassigned.add(var_name)
+                # Property assignments (self.field, obj.prop) don't use let/const
+                # so we skip them
+            elif isinstance(stmt, IRIf):
+                # Recursively analyze if/else blocks
+                if stmt.then_body:
+                    for s in stmt.then_body:
+                        analyze_stmt(s)
+                if stmt.else_body:
+                    for s in stmt.else_body:
+                        analyze_stmt(s)
+            elif isinstance(stmt, IRWhile):
+                if stmt.body:
+                    for s in stmt.body:
+                        analyze_stmt(s)
+            elif isinstance(stmt, IRFor) or isinstance(stmt, IRForCStyle):
+                if stmt.body:
+                    for s in stmt.body:
+                        analyze_stmt(s)
+            elif isinstance(stmt, IRTry):
+                if stmt.body:
+                    for s in stmt.body:
+                        analyze_stmt(s)
+                for catch in stmt.catches:
+                    if catch.body:
+                        for s in catch.body:
+                            analyze_stmt(s)
+                if stmt.finally_body:
+                    for s in stmt.finally_body:
+                        analyze_stmt(s)
+
+        for stmt in statements:
+            analyze_stmt(stmt)
+
+        return reassigned
 
     # ========================================================================
     # Indentation Management
@@ -126,8 +215,19 @@ class JavaScriptGenerator:
             JavaScript source code as string
         """
         self.required_imports.clear()
+        self.defined_classes.clear()
         lines = []
 
+        # BUG FIX v0.1.5: Add version header
+        try:
+            from assertlang import __version__
+            lines.append(f"// Generated by AssertLang v{__version__}")
+            lines.append(f"// Source: {module.metadata.get('source_file', 'unknown')}")
+            lines.append("// DO NOT EDIT - Regenerate from source instead")
+            lines.append("")
+        except ImportError:
+            pass  # Version info not available
+
         # Module docstring
         if module.metadata.get("doc"):
             lines.append(f'/**\n * {module.metadata["doc"]}\n */')
@@ -139,6 +239,19 @@ class JavaScriptGenerator:
         # Track function return types
         self._register_function_signatures(module)
 
+        # BUG FIX #5: Track all class names for 'new' keyword detection
+        for cls in module.classes:
+            self.defined_classes.add(cls.name)
+        for type_def in module.types:
+            self.defined_classes.add(type_def.name)
+        for enum in module.enums:
+            # For generic enums, track variant names as classes
+            if enum.generic_params:
+                for variant in enum.variants:
+                    self.defined_classes.add(variant.name)
+            else:
+                self.defined_classes.add(enum.name)
+
         # Contract runtime import if needed
         if self.required_imports:
             for imp in sorted(self.required_imports):
@@ -180,6 +293,36 @@ class JavaScriptGenerator:
             lines.append("")
             lines.append("")
 
+        # BUG FIX #1: Add module.exports for CommonJS compatibility
+        exports = []
+        # Export all top-level functions
+        for func in module.functions:
+            exports.append(func.name)
+        # Export all classes
+        for cls in module.classes:
+            exports.append(cls.name)
+        # Export all type definitions
+        for type_def in module.types:
+            exports.append(type_def.name)
+        # Export enums (either enum name or variant names for generic enums)
+        for enum in module.enums:
+            if enum.generic_params:
+                # Generic enums export their variant classes
+                for variant in enum.variants:
+                    exports.append(variant.name)
+                    # Also add the underscore version if it's a keyword
+                    if variant.name in ("None", "True", "False"):
+                        exports.append(f"{variant.name}_")
+            else:
+                # Regular enums export the enum itself
+                exports.append(enum.name)
+
+        if exports:
+            lines.append("")
+            lines.append("module.exports = {")
+            lines.append("    " + ",\n    ".join(exports))
+            lines.append("};")
+
         # Clean up and return
         result = "\n".join(lines)
         # Remove excessive blank lines
@@ -424,6 +567,9 @@ class JavaScriptGenerator:
         """Generate class method."""
         lines = []
 
+        # BUG FIX: Analyze which variables are reassigned in this method
+        self.reassigned_variables = self._analyze_reassignments(method.body if method.body else [])
+
         # Register parameter types
         for param in method.params:
             self.variable_types[param.name] = param.param_type
@@ -465,6 +611,9 @@ class JavaScriptGenerator:
         """Generate standalone function with contract checks."""
         lines = []
 
+        # BUG FIX: Analyze which variables are reassigned in this function
+        self.reassigned_variables = self._analyze_reassignments(func.body if func.body else [])
+
         # Register parameter types
         for param in func.params:
             self.variable_types[param.name] = param.param_type
@@ -763,8 +912,13 @@ class JavaScriptGenerator:
             if isinstance(stmt.target, str) and stmt.var_type:
                 self.variable_types[stmt.target] = stmt.var_type
 
+            # BUG FIX: Use let if variable is reassigned
             if stmt.is_declaration:
-                return f"{self.indent()}const {target} = {obj_literal};"
+                var_name = stmt.target if isinstance(stmt.target, str) else None
+                if var_name and var_name in self.reassigned_variables:
+                    return f"{self.indent()}let {target} = {obj_literal};"
+                else:
+                    return f"{self.indent()}const {target} = {obj_literal};"
             else:
                 return f"{self.indent()}{target} = {obj_literal};"
 
@@ -776,9 +930,22 @@ class JavaScriptGenerator:
         if isinstance(stmt.target, str) and stmt.var_type:
             self.variable_types[stmt.target] = stmt.var_type
 
-        # Use const for declarations, regular assignment otherwise
-        if stmt.is_declaration:
-            return f"{self.indent()}const {target} = {value};"
+        # BUG FIX #2: Property assignments (this.property) should never use 'const'
+        # Check if target is a property access (contains 'this.' or other object access)
+        is_property_assignment = isinstance(stmt.target, IRPropertyAccess) or (
+            isinstance(target, str) and ('.' in target or target.startswith('this'))
+        )
+
+        # BUG FIX: Use const for variable declarations only if not reassigned
+        # Use let for variables that will be reassigned later
+        if stmt.is_declaration and not is_property_assignment:
+            var_name = stmt.target if isinstance(stmt.target, str) else None
+            if var_name and var_name in self.reassigned_variables:
+                # Variable is reassigned later, use 'let'
+                return f"{self.indent()}let {target} = {value};"
+            else:
+                # Variable is never reassigned, use 'const'
+                return f"{self.indent()}const {target} = {value};"
         else:
             return f"{self.indent()}{target} = {value};"
 
@@ -964,6 +1131,9 @@ class JavaScriptGenerator:
             return self.generate_call(expr)
         elif isinstance(expr, IRPropertyAccess):
             obj = self.generate_expression(expr.object)
+            # BUG FIX #3: Convert Python's 'self' to JavaScript's 'this'
+            if obj == "self":
+                obj = "this"
             if expr.property == "length":
                 return f"{obj}.length"
             return f"{obj}.{expr.property}"
@@ -1005,14 +1175,30 @@ class JavaScriptGenerator:
         left = self.generate_expression(expr.left)
         right = self.generate_expression(expr.right)
 
+        # BUG FIX: Handle division specially for integer types
+        # JavaScript's / is always float division, we need Math.floor() for integer division
+        if expr.op == BinaryOperator.DIVIDE:
+            # Check if both operands are integers
+            left_is_int = self._is_integer_expression(expr.left)
+            right_is_int = self._is_integer_expression(expr.right)
+
+            if left_is_int and right_is_int:
+                # Integer division: use Math.floor()
+                return f"Math.floor({left} / {right})"
+            else:
+                # Float division: use regular /
+                return f"({left} / {right})"
+
+        # Handle floor division explicitly
+        if expr.op == BinaryOperator.FLOOR_DIVIDE:
+            return f"Math.floor({left} / {right})"
+
         op_map = {
             BinaryOperator.ADD: "+",
             BinaryOperator.SUBTRACT: "-",
             BinaryOperator.MULTIPLY: "*",
-            BinaryOperator.DIVIDE: "/",
             BinaryOperator.MODULO: "%",
             BinaryOperator.POWER: "**",
-            BinaryOperator.FLOOR_DIVIDE: "//",
             BinaryOperator.EQUAL: "===",
             BinaryOperator.NOT_EQUAL: "!==",
             BinaryOperator.LESS_THAN: "<",
@@ -1062,6 +1248,45 @@ class JavaScriptGenerator:
                     substr_arg = self.generate_expression(expr.args[1])
                     return f"{string_arg}.includes({substr_arg})"
 
+        # BUG FIX #4: Map Python built-in functions to JavaScript equivalents
+        if isinstance(expr.function, IRIdentifier):
+            func_name = expr.function.name
+
+            # Python built-ins to JavaScript mappings
+            if func_name == "str":
+                # str(x) → String(x)
+                if len(expr.args) == 1:
+                    arg = self.generate_expression(expr.args[0])
+                    return f"String({arg})"
+            elif func_name == "int":
+                # int(x) → Math.floor(x)
+                if len(expr.args) == 1:
+                    arg = self.generate_expression(expr.args[0])
+                    return f"Math.floor({arg})"
+            elif func_name == "float":
+                # float(x) → Number(x) or just x (JS numbers are all floats)
+                if len(expr.args) == 1:
+                    arg = self.generate_expression(expr.args[0])
+                    # In JavaScript, all numbers are already floating point
+                    # But we'll use Number() for explicit conversion
+                    return f"Number({arg})"
+            elif func_name == "bool":
+                # bool(x) → Boolean(x)
+                if len(expr.args) == 1:
+                    arg = self.generate_expression(expr.args[0])
+                    return f"Boolean({arg})"
+            elif func_name == "len":
+                # len(x) → x.length
+                if len(expr.args) == 1:
+                    arg = self.generate_expression(expr.args[0])
+                    return f"{arg}.length"
+
+            # BUG FIX #5: Add 'new' keyword for class constructor calls
+            if func_name in self.defined_classes:
+                # This is a constructor call - add 'new' keyword
+                args = [self.generate_expression(arg) for arg in expr.args]
+                return f"new {func_name}({', '.join(args)})"
+
         func = self.generate_expression(expr.function)
         args = [self.generate_expression(arg) for arg in expr.args]
         return f"{func}({', '.join(args)})"
