@@ -134,6 +134,13 @@ class PythonGeneratorV2:
         self.required_imports.clear()
         lines = []
 
+        # BUG FIX v0.1.5: Add version header
+        from assertlang import __version__
+        lines.append(f"# Generated by AssertLang v{__version__}")
+        lines.append(f"# Source: {module.metadata.get('source_file', 'unknown')}")
+        lines.append("# DO NOT EDIT - Regenerate from source instead")
+        lines.append("")
+
         # Module docstring
         if module.metadata.get("doc"):
             lines.append(f'"""{module.metadata["doc"]}"""')
@@ -152,6 +159,11 @@ class PythonGeneratorV2:
         lines.append("from __future__ import annotations")
         lines.append("")
 
+        # BUG FIX v0.1.5: Add AssertLang runtime imports
+        lines.append("# AssertLang Runtime")
+        lines.append("from assertlang.runtime import Ok, Error, Result")
+        lines.append("")
+
         # Special imports (enum, dataclass) - add to required
         if module.enums:
             self.required_imports.add("from enum import Enum")
@@ -1536,6 +1548,12 @@ class PythonGeneratorV2:
                     arg = self.generate_expression(expr.args[0])
                     return f"len({arg})"
 
+            # BUG FIX #3: list.length(x) → len(x)
+            if isinstance(obj, IRIdentifier) and obj.name == "list" and method == "length":
+                if len(expr.args) == 1:
+                    arg = self.generate_expression(expr.args[0])
+                    return f"len({arg})"
+
             # str.contains(s, substr) → substr in s
             if isinstance(obj, IRIdentifier) and obj.name == "str" and method == "contains":
                 if len(expr.args) == 2:
@@ -1580,24 +1598,14 @@ class PythonGeneratorV2:
                     # Return generator expression (without list())
                     return f"({body_expr} for {param_name} in {iterable})"
 
+        # BUG FIX #6: Use positional arguments for all constructors (including enum variants)
+        # Dataclasses support positional arguments, so no need for field_0=, field_1= syntax
         # Regular function call
-        if is_enum_variant and expr.args and not expr.kwargs:
-            # Enum variant constructor: Some(x) → Some(value=x)
-            # Use keyword argument for single-argument variants
-            if len(expr.args) == 1:
-                arg_value = self.generate_expression(expr.args[0])
-                return f"{func}(value={arg_value})"
-            else:
-                # Multiple arguments: use field_0, field_1, etc.
-                kwargs_list = [f"field_{i}={self.generate_expression(arg)}" for i, arg in enumerate(expr.args)]
-                return f"{func}({', '.join(kwargs_list)})"
-        else:
-            # Regular function call
-            args = [self.generate_expression(arg) for arg in expr.args]
-            kwargs = [f"{k}={self.generate_expression(v)}" for k, v in expr.kwargs.items()]
+        args = [self.generate_expression(arg) for arg in expr.args]
+        kwargs = [f"{k}={self.generate_expression(v)}" for k, v in expr.kwargs.items()]
 
-            all_args = args + kwargs
-            return f"{func}({', '.join(all_args)})"
+        all_args = args + kwargs
+        return f"{func}({', '.join(all_args)})"
 
     def generate_array(self, expr: IRArray) -> str:
         """Generate list literal."""
